# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr

class UpdatePasswordInsecureRequest(BaseModel):
    """
    UpdatePasswordInsecureRequest
    """
    password: StrictStr = Field(..., description="Set to the password value using cleartext. Hashes are never stored as cleartext. They are stored securely using cryptographic hash. OneLogin continuously upgrades the strength of the hash. Ensure that the value meets the password strength requirements set for the account.")
    password_confirmation: StrictStr = Field(..., description="Ensure that this value matches the password value exactly.")
    validate_policy: Optional[StrictBool] = Field(False, description="Will passwords validate against the User Policy. Defaults to false.")
    __properties = ["password", "password_confirmation", "validate_policy"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> UpdatePasswordInsecureRequest:
        """Create an instance of UpdatePasswordInsecureRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> UpdatePasswordInsecureRequest:
        """Create an instance of UpdatePasswordInsecureRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return UpdatePasswordInsecureRequest.parse_obj(obj)

        _obj = UpdatePasswordInsecureRequest.parse_obj({
            "password": obj.get("password"),
            "password_confirmation": obj.get("password_confirmation"),
            "validate_policy": obj.get("validate_policy") if obj.get("validate_policy") is not None else False
        })
        return _obj




# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr

class GetEnrolledFactors200ResponseDataOtpDevicesInner(BaseModel):
    """
    GetEnrolledFactors200ResponseDataOtpDevicesInner
    """
    active: Optional[StrictBool] = Field(None, description="True = enabled (used successfully for authentication at least once). False = pending (registered but never used).")
    default: Optional[StrictBool] = Field(None, description="True = is user’s default MFA device for OneLogin.")
    state_token: Optional[StrictStr] = Field(None, description="A short lived token that is required to Verify the Factor. This token expires in 120 seconds.")
    auth_factor_name: Optional[StrictStr] = Field(None, description="\"Official\" authentication factor name, as it appears to administrators in OneLogin.")
    phone_number: Optional[StrictStr] = Field(None, description="For OTP codes sent via SMS, the phone number receiving the SMS message.")
    type_display_name: Optional[StrictStr] = Field(None, description="Authentication factor display name as it appears to users upon initial registration, as defined by admins at Settings > Authentication Factors.")
    needs_trigger: Optional[StrictBool] = Field(None, description="true: You MUST Activate this Factor to trigger an SMS or Push notification before Verifying the OTP code. false: No Activation required. You can Verify the OTP immediately. MFA factors that provide both push notifications (user accepts notification) and pull code submission (user initiates code submission from device or enters it manually) should appear twice; once with needs_trigger: true and once with needs_trigger: false.")
    user_display_name: Optional[StrictStr] = Field(None, description="Authentication factor display name assigned by users when they enroll the device.")
    id: Optional[StrictInt] = Field(None, description="MFA device identifier.")
    __properties = ["active", "default", "state_token", "auth_factor_name", "phone_number", "type_display_name", "needs_trigger", "user_display_name", "id"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> GetEnrolledFactors200ResponseDataOtpDevicesInner:
        """Create an instance of GetEnrolledFactors200ResponseDataOtpDevicesInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> GetEnrolledFactors200ResponseDataOtpDevicesInner:
        """Create an instance of GetEnrolledFactors200ResponseDataOtpDevicesInner from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return GetEnrolledFactors200ResponseDataOtpDevicesInner.parse_obj(obj)

        _obj = GetEnrolledFactors200ResponseDataOtpDevicesInner.parse_obj({
            "active": obj.get("active"),
            "default": obj.get("default"),
            "state_token": obj.get("state_token"),
            "auth_factor_name": obj.get("auth_factor_name"),
            "phone_number": obj.get("phone_number"),
            "type_display_name": obj.get("type_display_name"),
            "needs_trigger": obj.get("needs_trigger"),
            "user_display_name": obj.get("user_display_name"),
            "id": obj.get("id")
        })
        return _obj




# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr
from onelogin.models.auth_server_configuration import AuthServerConfiguration

class AuthServer(BaseModel):
    """
    base resource for configuring api authorization in OneLogin
    """
    id: Optional[StrictInt] = Field(None, description="Auth server unique ID in Onelogin")
    name: StrictStr = Field(..., description="Name of the API.")
    description: StrictStr = Field(..., description="Description of what the API does.")
    configuration: AuthServerConfiguration = ...
    __properties = ["id", "name", "description", "configuration"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AuthServer:
        """Create an instance of AuthServer from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "id",
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of configuration
        if self.configuration:
            _dict['configuration'] = self.configuration.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AuthServer:
        """Create an instance of AuthServer from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return AuthServer.parse_obj(obj)

        _obj = AuthServer.parse_obj({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "configuration": AuthServerConfiguration.from_dict(obj.get("configuration")) if obj.get("configuration") is not None else None
        })
        return _obj




# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, conlist, validator
from onelogin.models.action_obj import ActionObj
from onelogin.models.condition import Condition

class Mapping(BaseModel):
    """
    Mapping
    """
    id: Optional[StrictInt] = None
    name: StrictStr = Field(..., description="The name of the mapping.")
    enabled: StrictBool = Field(..., description="Indicates if the mapping is enabled or not.")
    match: StrictStr = Field(..., description="Indicates how conditions should be matched.")
    position: StrictInt = Field(..., description="Indicates the order of the mapping. When `null` this will default to last position.")
    conditions: conlist(Condition) = Field(..., description="An array of conditions that the user must meet in order for the mapping to be applied.")
    actions: conlist(ActionObj) = Field(..., description="An array of actions that will be applied to the users that are matched by the conditions.")
    __properties = ["id", "name", "enabled", "match", "position", "conditions", "actions"]

    @validator('match')
    def match_validate_enum(cls, v):
        if v not in ('all', 'any'):
            raise ValueError("must be one of enum values ('all', 'any')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Mapping:
        """Create an instance of Mapping from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in conditions (list)
        _items = []
        if self.conditions:
            for _item in self.conditions:
                if _item:
                    _items.append(_item.to_dict())
            _dict['conditions'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in actions (list)
        _items = []
        if self.actions:
            for _item in self.actions:
                if _item:
                    _items.append(_item.to_dict())
            _dict['actions'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Mapping:
        """Create an instance of Mapping from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return Mapping.parse_obj(obj)

        _obj = Mapping.parse_obj({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "enabled": obj.get("enabled"),
            "match": obj.get("match"),
            "position": obj.get("position"),
            "conditions": [Condition.from_dict(_item) for _item in obj.get("conditions")] if obj.get("conditions") is not None else None,
            "actions": [ActionObj.from_dict(_item) for _item in obj.get("actions")] if obj.get("actions") is not None else None
        })
        return _obj




# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import onelogin
from onelogin.models.get_event_by_id200_response import GetEventById200Response  # noqa: E501
from onelogin.rest import ApiException

class TestGetEventById200Response(unittest.TestCase):
    """GetEventById200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test GetEventById200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetEventById200Response`
        """
        model = onelogin.models.get_event_by_id200_response.GetEventById200Response()  # noqa: E501
        if include_optional :
            return GetEventById200Response(
                status = onelogin.models.error.Error(
                    error = False, 
                    code = 200, 
                    type = 'Success', 
                    message = 'Success', ), 
                data = onelogin.models.event.event(
                    account_id = 56, 
                    actor_system = '', 
                    actor_user_id = 56, 
                    actor_user_name = '', 
                    adc_id = 56, 
                    app_name = '', 
                    app_id = 56, 
                    assumed_by_superadmin_or_reseller = 56, 
                    assuming_acting_user_id = 56, 
                    certificate_id = 56, 
                    client_id = '', 
                    created_at = '', 
                    custom_message = '', 
                    directory_sync_run_id = 56, 
                    error_description = '', 
                    event_type_id = 1, 
                    group_name = '', 
                    group_id = 56, 
                    id = 56, 
                    ipaddr = '', 
                    mapping_id = 56, 
                    notes = '', 
                    object_id = 56, 
                    otp_device_id = 56, 
                    otp_device_name = '', 
                    param = '', 
                    policy_id = 56, 
                    policy_name = '', 
                    policy_type = '', 
                    privilege_id = 56, 
                    proxy_ip = '', 
                    radius_config_id = 56, 
                    resolved_at = '', 
                    resource_type_id = 56, 
                    risk_cookie_id = '', 
                    risk_reasons = '', 
                    risk_score = 56, 
                    role_id = 56, 
                    role_name = '', 
                    service_directory_id = 56, 
                    solved = True, 
                    trusted_idp_id = 56, 
                    user_field_id = 56, 
                    user_id = 56, 
                    user_name = '', )
            )
        else :
            return GetEventById200Response(
        )
        """

    def testGetEventById200Response(self):
        """Test GetEventById200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr

class CreateFactorRegistrationRequest(BaseModel):
    """
    CreateFactorRegistrationRequest
    """
    factor_id: StrictInt = Field(..., description="The identifier of the factor to enroll the user with. See Get Available Factors for a list of possible id values.")
    display_name: StrictStr = Field(..., description="A name for the users device")
    expires_in: Optional[StrictStr] = Field(None, description="Defaults to 120. Valid values are: 120-900 seconds.")
    verified: Optional[StrictBool] = Field(None, description="Defaults to false. The following factors support verified = true as part of the initial registration request: OneLogin SMS, OneLogin Voice, OneLogin Email. When using verified = true it is critical that the supported factors have pre-verified values, most likely imported from an existing directory or by the users themselvdes. Factors such as Authenticator and OneLogin Protect do not support verification = true as the user interaction is required to verify the factor.")
    redirect_to: Optional[StrictStr] = Field(None, description="Only applies to Email MagicLink factor. Redirects MagicLink success page to specified URL after 2 seconds. Email must already be configured by the user.")
    custom_message: Optional[StrictStr] = Field(None, description="Only applies to SMS factor. A message template that will be sent via SMS. Max length of the message after template items are inserted is 160 characters including the OTP code. SMS must already be configured by the user. The following template variables can be included in the message. - {{otp_code}} - The security code. - {{otp_expiry}} - The number of minutes until the one time code expires.")
    __properties = ["factor_id", "display_name", "expires_in", "verified", "redirect_to", "custom_message"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CreateFactorRegistrationRequest:
        """Create an instance of CreateFactorRegistrationRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CreateFactorRegistrationRequest:
        """Create an instance of CreateFactorRegistrationRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return CreateFactorRegistrationRequest.parse_obj(obj)

        _obj = CreateFactorRegistrationRequest.parse_obj({
            "factor_id": obj.get("factor_id"),
            "display_name": obj.get("display_name"),
            "expires_in": obj.get("expires_in"),
            "verified": obj.get("verified"),
            "redirect_to": obj.get("redirect_to"),
            "custom_message": obj.get("custom_message")
        })
        return _obj




# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import onelogin
from onelogin.api.branding_service_templates_api import BrandingServiceTemplatesApi  # noqa: E501
from onelogin.rest import ApiException


class TestBrandingServiceTemplatesApi(unittest.TestCase):
    """BrandingServiceTemplatesApi unit test stubs"""

    def setUp(self):
        self.api = onelogin.api.branding_service_templates_api.BrandingServiceTemplatesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_message_template(self):
        """Test case for create_message_template

        Create Message Template  # noqa: E501
        """
        pass

    def test_delete_message_template(self):
        """Test case for delete_message_template

        Delete Message Template  # noqa: E501
        """
        pass

    def test_get_master_by_type(self):
        """Test case for get_master_by_type

        Get Master Template by Type  # noqa: E501
        """
        pass

    def test_get_message_template_by_id(self):
        """Test case for get_message_template_by_id

        Get Message Template  # noqa: E501
        """
        pass

    def test_get_template_by_locale(self):
        """Test case for get_template_by_locale

        Get Template by Type & Locale  # noqa: E501
        """
        pass

    def test_list_message_templates(self):
        """Test case for list_message_templates

        List Message Templates  # noqa: E501
        """
        pass

    def test_update_message_template_by_id(self):
        """Test case for update_message_template_by_id

        Update Message Template  # noqa: E501
        """
        pass

    def test_update_template_by_locale(self):
        """Test case for update_template_by_locale

        Update Template by Type & Locale  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import onelogin
from onelogin.api.vigilance_ai_api import VigilanceAIApi  # noqa: E501
from onelogin.rest import ApiException


class TestVigilanceAIApi(unittest.TestCase):
    """VigilanceAIApi unit test stubs"""

    def setUp(self):
        self.api = onelogin.api.vigilance_ai_api.VigilanceAIApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_risk_rule(self):
        """Test case for create_risk_rule

        Create Rule  # noqa: E501
        """
        pass

    def test_delete_risk_rule(self):
        """Test case for delete_risk_rule

        Delete Rule  # noqa: E501
        """
        pass

    def test_get_risk_rule(self):
        """Test case for get_risk_rule

        get Risk Rule  # noqa: E501
        """
        pass

    def test_get_risk_score(self):
        """Test case for get_risk_score

        Get a Risk Score  # noqa: E501
        """
        pass

    def test_get_risk_scores(self):
        """Test case for get_risk_scores

        Get Score Summary  # noqa: E501
        """
        pass

    def test_list_risk_rules(self):
        """Test case for list_risk_rules

        List Rules  # noqa: E501
        """
        pass

    def test_track_risk_event(self):
        """Test case for track_risk_event

        Track an Event  # noqa: E501
        """
        pass

    def test_update_risk_rule(self):
        """Test case for update_risk_rule

        Update Rule  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import apis into api package
from onelogin.api.api_auth_claims_api import APIAuthClaimsApi
from onelogin.api.api_auth_client_apps_api import APIAuthClientAppsApi
from onelogin.api.api_auth_scopes_api import APIAuthScopesApi
from onelogin.api.api_authorization_server_api import APIAuthorizationServerApi
from onelogin.api.app_rules_api import AppRulesApi
from onelogin.api.apps_api import AppsApi
from onelogin.api.branding_service_api import BrandingServiceApi
from onelogin.api.branding_service_smtp_api import BrandingServiceSMTPApi
from onelogin.api.branding_service_templates_api import BrandingServiceTemplatesApi
from onelogin.api.events_api import EventsApi
from onelogin.api.groups_api import GroupsApi
from onelogin.api.invite_links_api import InviteLinksApi
from onelogin.api.multi_factor_authentication_api import MultiFactorAuthenticationApi
from onelogin.api.multi_factor_authentication_v1_api import MultiFactorAuthenticationV1Api
from onelogin.api.o_auth2_api import OAuth2Api
from onelogin.api.privileges_api import PrivilegesApi
from onelogin.api.roles_api import RolesApi
from onelogin.api.saml_assertions_api import SAMLAssertionsApi
from onelogin.api.smart_hooks_api import SmartHooksApi
from onelogin.api.user_mappings_api import UserMappingsApi
from onelogin.api.users_v1_api import UsersV1Api
from onelogin.api.users_v2_api import UsersV2Api
from onelogin.api.vigilance_ai_api import VigilanceAIApi




# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import re  # noqa: F401

from pydantic import validate_arguments, ValidationError
from typing_extensions import Annotated

from pydantic import StrictInt, StrictStr

from typing import Any, Dict, List, Optional

from onelogin.models.connector import Connector
from onelogin.models.create_app200_response import CreateApp200Response
from onelogin.models.create_app_request import CreateAppRequest
from onelogin.models.generic_app import GenericApp
from onelogin.models.user import User

from onelogin.api_client import ApiClient
from onelogin.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class AppsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def create_app(self, content_type : Optional[StrictStr] = None, create_app_request : Optional[CreateAppRequest] = None, **kwargs) -> CreateApp200Response:  # noqa: E501
        """Create App  # noqa: E501

        Create App  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_app(content_type, create_app_request, async_req=True)
        >>> result = thread.get()

        :param content_type:
        :type content_type: str
        :param create_app_request:
        :type create_app_request: CreateAppRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CreateApp200Response
        """
        kwargs['_return_http_data_only'] = True
        return self.create_app_with_http_info(content_type, create_app_request, **kwargs)  # noqa: E501

    @validate_arguments
    def create_app_with_http_info(self, content_type : Optional[StrictStr] = None, create_app_request : Optional[CreateAppRequest] = None, **kwargs):  # noqa: E501
        """Create App  # noqa: E501

        Create App  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_app_with_http_info(content_type, create_app_request, async_req=True)
        >>> result = thread.get()

        :param content_type:
        :type content_type: str
        :param create_app_request:
        :type create_app_request: CreateAppRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CreateApp200Response, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'content_type',
            'create_app_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_app" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['content_type']:
            _header_params['Content-Type'] = _params['content_type']

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['create_app_request']:
            _body_params = _params['create_app_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['OAuth2']  # noqa: E501

        _response_types_map = {
            '200': "CreateApp200Response",
            '401': "Error",
            '422': "Error",
        }

        return self.api_client.call_api(
            '/api/2/apps', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def delete_app(self, app_id : StrictInt, **kwargs) -> None:  # noqa: E501
        """Delete App  # noqa: E501

        Delete App  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_app(app_id, async_req=True)
        >>> result = thread.get()

        :param app_id: (required)
        :type app_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_app_with_http_info(app_id, **kwargs)  # noqa: E501

    @validate_arguments
    def delete_app_with_http_info(self, app_id : StrictInt, **kwargs):  # noqa: E501
        """Delete App  # noqa: E501

        Delete App  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_app_with_http_info(app_id, async_req=True)
        >>> result = thread.get()

        :param app_id: (required)
        :type app_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'app_id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_app" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['app_id']:
            _path_params['app_id'] = _params['app_id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['OAuth2']  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/api/2/apps/{app_id}', 'DELETE',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def delete_app_parameter(self, app_id : StrictInt, parameter_id : StrictStr, **kwargs) -> None:  # noqa: E501
        """Delete Parameter from App  # noqa: E501

        Delete Parameter from App  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_app_parameter(app_id, parameter_id, async_req=True)
        >>> result = thread.get()

        :param app_id: (required)
        :type app_id: int
        :param parameter_id: (required)
        :type parameter_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_app_parameter_with_http_info(app_id, parameter_id, **kwargs)  # noqa: E501

    @validate_arguments
    def delete_app_parameter_with_http_info(self, app_id : StrictInt, parameter_id : StrictStr, **kwargs):  # noqa: E501
        """Delete Parameter from App  # noqa: E501

        Delete Parameter from App  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_app_parameter_with_http_info(app_id, parameter_id, async_req=True)
        >>> result = thread.get()

        :param app_id: (required)
        :type app_id: int
        :param parameter_id: (required)
        :type parameter_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'app_id',
            'parameter_id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_app_parameter" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['app_id']:
            _path_params['app_id'] = _params['app_id']

        if _params['parameter_id']:
            _path_params['parameter_id'] = _params['parameter_id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['OAuth2']  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/api/2/apps/{app_id}/parameters/{parameter_id}', 'DELETE',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_app(self, app_id : StrictInt, **kwargs) -> GenericApp:  # noqa: E501
        """Get App  # noqa: E501

        Get App  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_app(app_id, async_req=True)
        >>> result = thread.get()

        :param app_id: (required)
        :type app_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: GenericApp
        """
        kwargs['_return_http_data_only'] = True
        return self.get_app_with_http_info(app_id, **kwargs)  # noqa: E501

    @validate_arguments
    def get_app_with_http_info(self, app_id : StrictInt, **kwargs):  # noqa: E501
        """Get App  # noqa: E501

        Get App  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_app_with_http_info(app_id, async_req=True)
        >>> result = thread.get()

        :param app_id: (required)
        :type app_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(GenericApp, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'app_id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_app" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['app_id']:
            _path_params['app_id'] = _params['app_id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['OAuth2']  # noqa: E501

        _response_types_map = {
            '200': "GenericApp",
            '401': "AltErr",
            '404': "AltErr",
        }

        return self.api_client.call_api(
            '/api/2/apps/{app_id}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_app_users(self, app_id : StrictInt, **kwargs) -> List[User]:  # noqa: E501
        """Get App Users  # noqa: E501

        Get App Users  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_app_users(app_id, async_req=True)
        >>> result = thread.get()

        :param app_id: (required)
        :type app_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: List[User]
        """
        kwargs['_return_http_data_only'] = True
        return self.get_app_users_with_http_info(app_id, **kwargs)  # noqa: E501

    @validate_arguments
    def get_app_users_with_http_info(self, app_id : StrictInt, **kwargs):  # noqa: E501
        """Get App Users  # noqa: E501

        Get App Users  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_app_users_with_http_info(app_id, async_req=True)
        >>> result = thread.get()

        :param app_id: (required)
        :type app_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(List[User], status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'app_id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_app_users" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['app_id']:
            _path_params['app_id'] = _params['app_id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['OAuth2']  # noqa: E501

        _response_types_map = {
            '200': "List[User]",
            '401': "AltErr",
        }

        return self.api_client.call_api(
            '/api/2/apps/{app_id}/users', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def list_apps(self, **kwargs) -> List[GenericApp]:  # noqa: E501
        """List Apps  # noqa: E501

        List Apps  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_apps(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: List[GenericApp]
        """
        kwargs['_return_http_data_only'] = True
        return self.list_apps_with_http_info(**kwargs)  # noqa: E501

    @validate_arguments
    def list_apps_with_http_info(self, **kwargs):  # noqa: E501
        """List Apps  # noqa: E501

        List Apps  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_apps_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(List[GenericApp], status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_apps" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['OAuth2']  # noqa: E501

        _response_types_map = {
            '200': "List[GenericApp]",
            '401': "AltErr",
            '422': "AltErr",
        }

        return self.api_client.call_api(
            '/api/2/apps', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def list_connectors(self, name : Optional[StrictStr] = None, **kwargs) -> Connector:  # noqa: E501
        """List Connectors  # noqa: E501

        List Connectors  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_connectors(name, async_req=True)
        >>> result = thread.get()

        :param name:
        :type name: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: Connector
        """
        kwargs['_return_http_data_only'] = True
        return self.list_connectors_with_http_info(name, **kwargs)  # noqa: E501

    @validate_arguments
    def list_connectors_with_http_info(self, name : Optional[StrictStr] = None, **kwargs):  # noqa: E501
        """List Connectors  # noqa: E501

        List Connectors  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_connectors_with_http_info(name, async_req=True)
        >>> result = thread.get()

        :param name:
        :type name: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(Connector, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'name'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_connectors" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('name') is not None:  # noqa: E501
            _query_params.append(('name', _params['name']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['OAuth2']  # noqa: E501

        _response_types_map = {
            '200': "Connector",
            '401': "AltErr",
            '422': "AltErr",
        }

        return self.api_client.call_api(
            '/api/2/connectors', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def update_app(self, app_id : StrictInt, request_body : Optional[Dict[str, Any]] = None, **kwargs) -> GenericApp:  # noqa: E501
        """Update App  # noqa: E501

        Update App  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_app(app_id, request_body, async_req=True)
        >>> result = thread.get()

        :param app_id: (required)
        :type app_id: int
        :param request_body:
        :type request_body: Dict[str, object]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: GenericApp
        """
        kwargs['_return_http_data_only'] = True
        return self.update_app_with_http_info(app_id, request_body, **kwargs)  # noqa: E501

    @validate_arguments
    def update_app_with_http_info(self, app_id : StrictInt, request_body : Optional[Dict[str, Any]] = None, **kwargs):  # noqa: E501
        """Update App  # noqa: E501

        Update App  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_app_with_http_info(app_id, request_body, async_req=True)
        >>> result = thread.get()

        :param app_id: (required)
        :type app_id: int
        :param request_body:
        :type request_body: Dict[str, object]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(GenericApp, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'app_id',
            'request_body'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_app" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['app_id']:
            _path_params['app_id'] = _params['app_id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['request_body']:
            _body_params = _params['request_body']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['OAuth2']  # noqa: E501

        _response_types_map = {
            '200': "GenericApp",
            '401': "AltErr",
            '404': "AltErr",
        }

        return self.api_client.call_api(
            '/api/2/apps/{app_id}', 'PUT',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import onelogin
from onelogin.models.create_app200_response import CreateApp200Response  # noqa: E501
from onelogin.rest import ApiException

class TestCreateApp200Response(unittest.TestCase):
    """CreateApp200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CreateApp200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateApp200Response`
        """
        model = onelogin.models.create_app200_response.CreateApp200Response()  # noqa: E501
        if include_optional :
            return CreateApp200Response(
                id = 775664, 
                name = 'A Sample App', 
                visible = True, 
                description = '', 
                notes = 'This app is in beta.', 
                icon_url = '/images/missing_connector_icon/square/old_original.png', 
                auth_method = 8, 
                policy_id = 56, 
                allow_assumed_signin = False, 
                tab_id = 196885, 
                connector_id = 108419, 
                created_at = '2018-04-12T21:50:42Z', 
                updated_at = '2019-05-16T19:20:34Z', 
                role_ids = [192513], 
                provisioning = onelogin.models.generic_app_provisioning.generic_app_provisioning(
                    enabled = True, ), 
                parameters = { }, 
                enforcement_point = onelogin.models.enforcement_point.enforcement_point(
                    require_sitewide_authentication = False, 
                    conditions = '', 
                    session_expiry_fixed = {"value":30,"unit":1}, 
                    session_expiry_inactivity = {"value":30,"unit":1}, 
                    permissions = 'allow', 
                    token = 'b491c647f5e0cff854ad606722ac98342b4b0882', 
                    target = '', 
                    resources = [{"resource_id":809,"conditions":"","is_path_regex":false,"permissions":"allow","require_auth":false,"path":"/"}], 
                    context_root = '/', 
                    use_target_host_header = False, 
                    vhost = '', 
                    landing_page = '', 
                    case_sensitive = False, ), 
                configuration = onelogin.models.configuration_saml.configuration_saml(
                    signature_algorithm = 'SHA-512', 
                    certificate_id = 123456, ), 
                sso = onelogin.models.sso_saml.sso_saml(
                    metadata_url = 'https://app.onelogin.com/saml/metadata/5772393d-2ad3-47d6-a64f-2339b1028291', 
                    acs_url = 'https://sharkbytes.onelogin.com/trust/saml2/http-post/sso/928532', 
                    sls_url = 'https://sharkbytes.onelogin.com/trust/saml2/http-redirect/slo/928532', 
                    issuer = 'https://app.onelogin.com/saml/metadata/5772393d-2ad3-47d6-a64f-2339b1028291', 
                    certificate = onelogin.models.sso_saml_certificate.sso_saml_certificate(
                        id = 170216, 
                        name = 'My Companies SAML Certificate', 
                        value = 'c6d814d032f000d9c03bc79727265', ), )
            )
        else :
            return CreateApp200Response(
                name = 'A Sample App',
                visible = True,
                description = '',
                policy_id = 56,
                connector_id = 108419,
                configuration = onelogin.models.configuration_saml.configuration_saml(
                    signature_algorithm = 'SHA-512', 
                    certificate_id = 123456, ),
        )
        """

    def testCreateApp200Response(self):
        """Test CreateApp200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, conlist
from onelogin.models.app_parameters import AppParameters
from onelogin.models.auth_method import AuthMethod
from onelogin.models.enforcement_point import EnforcementPoint
from onelogin.models.generic_app_provisioning import GenericAppProvisioning

class GenericApp(BaseModel):
    """
    GenericApp
    """
    id: Optional[StrictInt] = Field(None, description="Apps unique ID in OneLogin.")
    name: Optional[StrictStr] = Field(None, description="The name of the app.")
    visible: Optional[StrictBool] = Field(None, description="Indicates if the app is visible in the OneLogin portal.")
    description: Optional[StrictStr] = Field(None, description="Freeform description of the app.")
    notes: Optional[StrictStr] = Field(None, description="Freeform notes about the app.")
    icon_url: Optional[StrictStr] = Field(None, description="A link to the apps icon url")
    auth_method: Optional[AuthMethod] = None
    policy_id: Optional[StrictInt] = Field(None, description="The security policy assigned to the app.")
    allow_assumed_signin: Optional[StrictBool] = Field(None, description="Indicates whether or not administrators can access the app as a user that they have assumed control over.")
    tab_id: Optional[StrictInt] = Field(None, description="ID of the OneLogin portal tab that the app is assigned to.")
    connector_id: Optional[StrictInt] = Field(None, description="ID of the connector to base the app from.")
    created_at: Optional[StrictStr] = Field(None, description="the date the app was created")
    updated_at: Optional[StrictStr] = Field(None, description="the date the app was last updated")
    role_ids: Optional[conlist(StrictInt)] = Field(None, description="List of Role IDs that are assigned to the app. On App Create or Update the entire array is replaced with the values provided.")
    provisioning: Optional[GenericAppProvisioning] = None
    parameters: Optional[AppParameters] = None
    enforcement_point: Optional[EnforcementPoint] = None
    additional_properties: Dict[str, Any] = {}
    __properties = ["id", "name", "visible", "description", "notes", "icon_url", "auth_method", "policy_id", "allow_assumed_signin", "tab_id", "connector_id", "created_at", "updated_at", "role_ids", "provisioning", "parameters", "enforcement_point"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> GenericApp:
        """Create an instance of GenericApp from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "id",
                            "additional_properties"
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of provisioning
        if self.provisioning:
            _dict['provisioning'] = self.provisioning.to_dict()
        # override the default output from pydantic by calling `to_dict()` of parameters
        if self.parameters:
            _dict['parameters'] = self.parameters.to_dict()
        # override the default output from pydantic by calling `to_dict()` of enforcement_point
        if self.enforcement_point:
            _dict['enforcement_point'] = self.enforcement_point.to_dict()
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> GenericApp:
        """Create an instance of GenericApp from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return GenericApp.parse_obj(obj)

        _obj = GenericApp.parse_obj({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "visible": obj.get("visible"),
            "description": obj.get("description"),
            "notes": obj.get("notes"),
            "icon_url": obj.get("icon_url"),
            "auth_method": obj.get("auth_method"),
            "policy_id": obj.get("policy_id"),
            "allow_assumed_signin": obj.get("allow_assumed_signin"),
            "tab_id": obj.get("tab_id"),
            "connector_id": obj.get("connector_id"),
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at"),
            "role_ids": obj.get("role_ids"),
            "provisioning": GenericAppProvisioning.from_dict(obj.get("provisioning")) if obj.get("provisioning") is not None else None,
            "parameters": AppParameters.from_dict(obj.get("parameters")) if obj.get("parameters") is not None else None,
            "enforcement_point": EnforcementPoint.from_dict(obj.get("enforcement_point")) if obj.get("enforcement_point") is not None else None
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj




# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr
from onelogin.models.auth_method import AuthMethod

class Connector(BaseModel):
    """
    Connector
    """
    id: Optional[StrictInt] = Field(None, description="Connectors unique ID in OneLogin.")
    name: Optional[StrictStr] = Field(None, description="Name of Connector")
    icon_url: Optional[StrictStr] = Field(None, description="A link to the icon's url.")
    auth_method: Optional[AuthMethod] = None
    allows_new_parameters: Optional[StrictBool] = Field(None, description="Indicates if apps created using this connector will be allowed to create custom parameters.")
    __properties = ["id", "name", "icon_url", "auth_method", "allows_new_parameters"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Connector:
        """Create an instance of Connector from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Connector:
        """Create an instance of Connector from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return Connector.parse_obj(obj)

        _obj = Connector.parse_obj({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "icon_url": obj.get("icon_url"),
            "auth_method": obj.get("auth_method"),
            "allows_new_parameters": obj.get("allows_new_parameters")
        })
        return _obj




# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import onelogin
from onelogin.models.enforcement_point import EnforcementPoint  # noqa: E501
from onelogin.rest import ApiException

class TestEnforcementPoint(unittest.TestCase):
    """EnforcementPoint unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test EnforcementPoint
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `EnforcementPoint`
        """
        model = onelogin.models.enforcement_point.EnforcementPoint()  # noqa: E501
        if include_optional :
            return EnforcementPoint(
                require_sitewide_authentication = False, 
                conditions = '', 
                session_expiry_fixed = {"value":30,"unit":1}, 
                session_expiry_inactivity = {"value":30,"unit":1}, 
                permissions = 'allow', 
                token = 'b491c647f5e0cff854ad606722ac98342b4b0882', 
                target = '', 
                resources = [{"resource_id":809,"conditions":"","is_path_regex":false,"permissions":"allow","require_auth":false,"path":"/"}], 
                context_root = '/', 
                use_target_host_header = False, 
                vhost = '', 
                landing_page = '', 
                case_sensitive = False
            )
        else :
            return EnforcementPoint(
        )
        """

    def testEnforcementPoint(self):
        """Test EnforcementPoint"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictInt

class LockAccountUserRequest(BaseModel):
    """
    LockAccountUserRequest
    """
    locked_until: StrictInt = Field(..., description="Set to the number of minutes for which you want to lock the user account. Set to 0 if you want to lock the user account based on the Lock effective period set in the policy assigned to the user. If no policy is assigned to the user, setting this value to 0 will lock the user’s account until you unlock it Note that this value can not be less time that the Lock Effective Period specified on a user policy.")
    __properties = ["locked_until"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> LockAccountUserRequest:
        """Create an instance of LockAccountUserRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> LockAccountUserRequest:
        """Create an instance of LockAccountUserRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return LockAccountUserRequest.parse_obj(obj)

        _obj = LockAccountUserRequest.parse_obj({
            "locked_until": obj.get("locked_until")
        })
        return _obj




# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import onelogin
from onelogin.api.multi_factor_authentication_api import MultiFactorAuthenticationApi  # noqa: E501
from onelogin.rest import ApiException


class TestMultiFactorAuthenticationApi(unittest.TestCase):
    """MultiFactorAuthenticationApi unit test stubs"""

    def setUp(self):
        self.api = onelogin.api.multi_factor_authentication_api.MultiFactorAuthenticationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_device_verification(self):
        """Test case for create_device_verification

        Create Device Verification  # noqa: E501
        """
        pass

    def test_create_factor_registration(self):
        """Test case for create_factor_registration

        Create Factor Registration  # noqa: E501
        """
        pass

    def test_delete_enrolled_factor(self):
        """Test case for delete_enrolled_factor

        Delete Enrolled Factor  # noqa: E501
        """
        pass

    def test_generate_otp(self):
        """Test case for generate_otp

        Generate MFA token  # noqa: E501
        """
        pass

    def test_get_auth_factors(self):
        """Test case for get_auth_factors

        Get User Factors  # noqa: E501
        """
        pass

    def test_get_authentication_devices(self):
        """Test case for get_authentication_devices

        Get User Devices  # noqa: E501
        """
        pass

    def test_get_user_registration(self):
        """Test case for get_user_registration

        Get User Registration  # noqa: E501
        """
        pass

    def test_get_user_verification(self):
        """Test case for get_user_verification

        Get User Verification  # noqa: E501
        """
        pass

    def test_verify_user_registration(self):
        """Test case for verify_user_registration

        Verify User Registration  # noqa: E501
        """
        pass

    def test_verify_user_verification(self):
        """Test case for verify_user_verification

        Verify User Verification  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import onelogin
from onelogin.api.app_rules_api import AppRulesApi  # noqa: E501
from onelogin.rest import ApiException


class TestAppRulesApi(unittest.TestCase):
    """AppRulesApi unit test stubs"""

    def setUp(self):
        self.api = onelogin.api.app_rules_api.AppRulesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_app_rule(self):
        """Test case for create_app_rule

        """
        pass

    def test_delete_rule(self):
        """Test case for delete_rule

        Delete Rule  # noqa: E501
        """
        pass

    def test_get_app_rule(self):
        """Test case for get_app_rule

        Get Rule  # noqa: E501
        """
        pass

    def test_list_action_valies(self):
        """Test case for list_action_valies

        List Actions Values  # noqa: E501
        """
        pass

    def test_list_actions(self):
        """Test case for list_actions

        List Actions  # noqa: E501
        """
        pass

    def test_list_app_rules(self):
        """Test case for list_app_rules

        List Rules  # noqa: E501
        """
        pass

    def test_list_condition_operators(self):
        """Test case for list_condition_operators

        List Conditions Operators  # noqa: E501
        """
        pass

    def test_list_condition_values(self):
        """Test case for list_condition_values

        List Conditions Values  # noqa: E501
        """
        pass

    def test_list_conditions(self):
        """Test case for list_conditions

        List Conditions  # noqa: E501
        """
        pass

    def test_sort_app_rules(self):
        """Test case for sort_app_rules

        Bulk Sort  # noqa: E501
        """
        pass

    def test_update_app_rule(self):
        """Test case for update_app_rule

        Update Rule  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import onelogin
from onelogin.api.saml_assertions_api import SAMLAssertionsApi  # noqa: E501
from onelogin.rest import ApiException


class TestSAMLAssertionsApi(unittest.TestCase):
    """SAMLAssertionsApi unit test stubs"""

    def setUp(self):
        self.api = onelogin.api.saml_assertions_api.SAMLAssertionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_generate_saml_assert(self):
        """Test case for generate_saml_assert

        Generate SAML Assertion  # noqa: E501
        """
        pass

    def test_generate_saml_assert2(self):
        """Test case for generate_saml_assert2

        Generate SAML Assertion  # noqa: E501
        """
        pass

    def test_ver_factor_saml(self):
        """Test case for ver_factor_saml

        Verify Factor SAML  # noqa: E501
        """
        pass

    def test_ver_factor_saml2(self):
        """Test case for ver_factor_saml2

        Verify Factor SAML  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import onelogin
from onelogin.api.users_v1_api import UsersV1Api  # noqa: E501
from onelogin.rest import ApiException


class TestUsersV1Api(unittest.TestCase):
    """UsersV1Api unit test stubs"""

    def setUp(self):
        self.api = onelogin.api.users_v1_api.UsersV1Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_roles_to_user(self):
        """Test case for add_roles_to_user

        Add Roles for a User  # noqa: E501
        """
        pass

    def test_create_user(self):
        """Test case for create_user

        Create a User  # noqa: E501
        """
        pass

    def test_delete_user(self):
        """Test case for delete_user

        Delete a User  # noqa: E501
        """
        pass

    def test_get_custom_attributes(self):
        """Test case for get_custom_attributes

        Get Custom Attributes  # noqa: E501
        """
        pass

    def test_get_user_apps(self):
        """Test case for get_user_apps

        Get Apps for a User  # noqa: E501
        """
        pass

    def test_get_user_by_id(self):
        """Test case for get_user_by_id

        Get User by ID  # noqa: E501
        """
        pass

    def test_get_user_roles(self):
        """Test case for get_user_roles

        Get Roles for a User  # noqa: E501
        """
        pass

    def test_list_users(self):
        """Test case for list_users

        List Users  # noqa: E501
        """
        pass

    def test_lock_account_user(self):
        """Test case for lock_account_user

        Lock User Account  # noqa: E501
        """
        pass

    def test_log_out_user(self):
        """Test case for log_out_user

        Log User Out  # noqa: E501
        """
        pass

    def test_remove_user_role(self):
        """Test case for remove_user_role

        Remove Roles for a User  # noqa: E501
        """
        pass

    def test_set_user_state(self):
        """Test case for set_user_state

        Set User State  # noqa: E501
        """
        pass

    def test_update_password_insecure(self):
        """Test case for update_password_insecure

        Set Password Using ID in Cleartext  # noqa: E501
        """
        pass

    def test_update_password_secure(self):
        """Test case for update_password_secure

        Set Password Using ID and SHA-256 and Salt  # noqa: E501
        """
        pass

    def test_update_user(self):
        """Test case for update_user

        Update a User  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import onelogin
from onelogin.api.o_auth2_api import OAuth2Api  # noqa: E501
from onelogin.rest import ApiException


class TestOAuth2Api(unittest.TestCase):
    """OAuth2Api unit test stubs"""

    def setUp(self):
        self.api = onelogin.api.o_auth2_api.OAuth2Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_generate_token(self):
        """Test case for generate_token

        Generate Token  # noqa: E501
        """
        pass

    def test_get_rate_limit(self):
        """Test case for get_rate_limit

        Get Rate Limit  # noqa: E501
        """
        pass

    def test_revoke_tokens(self):
        """Test case for revoke_tokens

        Revoke Tokens  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import onelogin
from onelogin.models.get_enrolled_factors200_response import GetEnrolledFactors200Response  # noqa: E501
from onelogin.rest import ApiException

class TestGetEnrolledFactors200Response(unittest.TestCase):
    """GetEnrolledFactors200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test GetEnrolledFactors200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetEnrolledFactors200Response`
        """
        model = onelogin.models.get_enrolled_factors200_response.GetEnrolledFactors200Response()  # noqa: E501
        if include_optional :
            return GetEnrolledFactors200Response(
                status = onelogin.models.error.Error(
                    error = False, 
                    code = 200, 
                    type = 'Success', 
                    message = 'Success', ), 
                data = onelogin.models.get_enrolled_factors_200_response_data.getEnrolledFactors_200_response_data(
                    otp_devices = [
                        onelogin.models.get_enrolled_factors_200_response_data_otp_devices_inner.getEnrolledFactors_200_response_data_otp_devices_inner(
                            active = True, 
                            default = False, 
                            state_token = 'f2402de2b446abd86ea5aa1f79b3fa72b4befacd', 
                            auth_factor_name = 'Onelogin SMS', 
                            phone_number = '+1xxxxxxxxxx', 
                            type_display_name = 'Onelogin SMS', 
                            needs_trigger = True, 
                            user_display_name = 'Rich's Phone', 
                            id = 525509, )
                        ], )
            )
        else :
            return GetEnrolledFactors200Response(
        )
        """

    def testGetEnrolledFactors200Response(self):
        """Test GetEnrolledFactors200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import onelogin
from onelogin.api.branding_service_smtp_api import BrandingServiceSMTPApi  # noqa: E501
from onelogin.rest import ApiException


class TestBrandingServiceSMTPApi(unittest.TestCase):
    """BrandingServiceSMTPApi unit test stubs"""

    def setUp(self):
        self.api = onelogin.api.branding_service_smtp_api.BrandingServiceSMTPApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_email_settings(self):
        """Test case for delete_email_settings

        Delete Custom Email Settings  # noqa: E501
        """
        pass

    def test_get_email_settings(self):
        """Test case for get_email_settings

        Get Email Settings  # noqa: E501
        """
        pass

    def test_update_email_settings(self):
        """Test case for update_email_settings

        Update Email Settings  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field, StrictStr, conlist, validator

class PrivilegePrivilegeStatementInner(BaseModel):
    """
    PrivilegePrivilegeStatementInner
    """
    effect: StrictStr = Field(..., alias="Effect", description="Set to “Allow.” By default, all actions are denied, this Statement allows the listed actions to be executed.")
    action: conlist(StrictStr) = Field(..., alias="Action", description="An array of strings that represent actions within OneLogin. Actions are prefixed with the class of object they are related to and followed by a specific action for the given class. e.g. users:List, where the class is users and the specific action is List. Don’t mix classes within an Action array. To create a privilege that includes multiple different classes, create multiple statements. A wildcard * that includes all actions is supported. Use wildcards to create a Super User privilege.")
    scope: conlist(StrictStr) = Field(..., alias="Scope", description="Target the privileged action against specific resources with the scope. The scope pattern is the class of object used by the Action, followed by an ID that represents a resource in OneLogin. e.g. apps/1234, where apps is the class and 1234 is the ID of an app. The wildcard * is supported and indicates that all resources of the class type declared, in the Action, are in scope. The Action and Scope classes must match. However, there is an exception, a scope of roles/{role_id} can be combined with Actions on the user or app class. The exception allows you to target groups of users or apps with specific actions.")
    __properties = ["Effect", "Action", "Scope"]

    @validator('action')
    def action_validate_enum(cls, v):
        for i in v:
            if i not in ('Apps:Create', 'Apps:Delete', 'Apps:List', 'Apps:Get', 'Apps:Update', 'Apps:ManageConnectors', 'Apps:ManageRoles', 'Apps:ManageTabs', 'Apps:ManageUsers', 'Apps:ReapplyMappings', 'Users:Create', 'Users:Delete', 'Users:List', 'Users:Get', 'Users:Update', 'Users:AssumeUser', 'Users:ManageApps', 'Users:Unlock', 'Users:GenerateTempMfaToken', 'Users:ResetPassword', 'Users:ReapplyMappings', 'Users:ManageLicense', 'Users:Invite', 'Users:ManageRoles', 'Roles:Create', 'Roles:Get', 'Roles:List', 'Roles:Update', 'Roles:Delete', 'Roles:ManageUsers', 'Roles:ManageApps', 'Reports:Create', 'Reports:Get', 'Reports:List', 'Reports:Update', 'Reports:Delete', 'Reports:Clone', 'Events:Get', 'Events:List', 'Groups:Create', 'Groups:Get', 'Groups:List', 'Groups:Update', 'Groups:Delete', 'Policies:Create', 'Policies:Get', 'Policies:List', 'Policies:Update', 'Policies:Delete', 'Policies:SetDefault'):
                raise ValueError("each list item must be one of ('Apps:Create', 'Apps:Delete', 'Apps:List', 'Apps:Get', 'Apps:Update', 'Apps:ManageConnectors', 'Apps:ManageRoles', 'Apps:ManageTabs', 'Apps:ManageUsers', 'Apps:ReapplyMappings', 'Users:Create', 'Users:Delete', 'Users:List', 'Users:Get', 'Users:Update', 'Users:AssumeUser', 'Users:ManageApps', 'Users:Unlock', 'Users:GenerateTempMfaToken', 'Users:ResetPassword', 'Users:ReapplyMappings', 'Users:ManageLicense', 'Users:Invite', 'Users:ManageRoles', 'Roles:Create', 'Roles:Get', 'Roles:List', 'Roles:Update', 'Roles:Delete', 'Roles:ManageUsers', 'Roles:ManageApps', 'Reports:Create', 'Reports:Get', 'Reports:List', 'Reports:Update', 'Reports:Delete', 'Reports:Clone', 'Events:Get', 'Events:List', 'Groups:Create', 'Groups:Get', 'Groups:List', 'Groups:Update', 'Groups:Delete', 'Policies:Create', 'Policies:Get', 'Policies:List', 'Policies:Update', 'Policies:Delete', 'Policies:SetDefault')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PrivilegePrivilegeStatementInner:
        """Create an instance of PrivilegePrivilegeStatementInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PrivilegePrivilegeStatementInner:
        """Create an instance of PrivilegePrivilegeStatementInner from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return PrivilegePrivilegeStatementInner.parse_obj(obj)

        _obj = PrivilegePrivilegeStatementInner.parse_obj({
            "effect": obj.get("Effect"),
            "action": obj.get("Action"),
            "scope": obj.get("Scope")
        })
        return _obj




# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, validator

class GetUserApps200ResponseInner(BaseModel):
    """
    GetUserApps200ResponseInner
    """
    id: Optional[StrictInt] = Field(None, description="The App ID")
    icon_url: Optional[StrictStr] = Field(None, description="A url for the icon that represents the app in the OneLogin portal")
    extension: Optional[StrictBool] = Field(None, description="Boolean that indicates if the OneLogin browser extension is required to launch this app.")
    login_id: Optional[StrictInt] = Field(None, description="Unqiue identifier for this user and app combination.")
    name: Optional[StrictStr] = Field(None, description="The name of the app.")
    provisioning_status: Optional[StrictStr] = None
    provisioning_state: Optional[StrictStr] = Field(None, description="If provisioning is enabled this indicates the state of provisioning for the given user.")
    provisioning_enabled: Optional[StrictBool] = Field(None, description="Indicates if provisioning is enabled for this app.")
    __properties = ["id", "icon_url", "extension", "login_id", "name", "provisioning_status", "provisioning_state", "provisioning_enabled"]

    @validator('provisioning_status')
    def provisioning_status_validate_enum(cls, v):
        if v is None:
            return v
        if v not in ('enabling', 'disabling', 'enabling_pending_approval', 'disabling_pendding_approval', 'enabled', 'disabled', 'disabling_failed', 'enabling_failed'):
            raise ValueError("must be one of enum values ('enabling', 'disabling', 'enabling_pending_approval', 'disabling_pendding_approval', 'enabled', 'disabled', 'disabling_failed', 'enabling_failed')")
        return v

    @validator('provisioning_state')
    def provisioning_state_validate_enum(cls, v):
        if v is None:
            return v
        if v not in ('unknown', 'provisioning', 'modifying', 'deleting', 'provisioning_pending_approval', 'deleting_pending_approval', 'modifying_pending_approval', 'linking', 'provisioned', 'deleted', 'modifying_failed', 'provisioning_failed', 'deleting_failed', 'linking_failed', 'disabled', 'nonexistent', 'modifying_pending_approval_then_disabled'):
            raise ValueError("must be one of enum values ('unknown', 'provisioning', 'modifying', 'deleting', 'provisioning_pending_approval', 'deleting_pending_approval', 'modifying_pending_approval', 'linking', 'provisioned', 'deleted', 'modifying_failed', 'provisioning_failed', 'deleting_failed', 'linking_failed', 'disabled', 'nonexistent', 'modifying_pending_approval_then_disabled')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> GetUserApps200ResponseInner:
        """Create an instance of GetUserApps200ResponseInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> GetUserApps200ResponseInner:
        """Create an instance of GetUserApps200ResponseInner from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return GetUserApps200ResponseInner.parse_obj(obj)

        _obj = GetUserApps200ResponseInner.parse_obj({
            "id": obj.get("id"),
            "icon_url": obj.get("icon_url"),
            "extension": obj.get("extension"),
            "login_id": obj.get("login_id"),
            "name": obj.get("name"),
            "provisioning_status": obj.get("provisioning_status"),
            "provisioning_state": obj.get("provisioning_state"),
            "provisioning_enabled": obj.get("provisioning_enabled")
        })
        return _obj




# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import onelogin
from onelogin.models.verb import Verb  # noqa: E501
from onelogin.rest import ApiException

class TestVerb(unittest.TestCase):
    """Verb unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testVerb(self):
        """Test Verb"""
        # inst = Verb()

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


__version__ = "3.1.4"

# import apis into sdk package
from onelogin.api.api_auth_claims_api import APIAuthClaimsApi
from onelogin.api.api_auth_client_apps_api import APIAuthClientAppsApi
from onelogin.api.api_auth_scopes_api import APIAuthScopesApi
from onelogin.api.api_authorization_server_api import APIAuthorizationServerApi
from onelogin.api.app_rules_api import AppRulesApi
from onelogin.api.apps_api import AppsApi
from onelogin.api.branding_service_api import BrandingServiceApi
from onelogin.api.branding_service_smtp_api import BrandingServiceSMTPApi
from onelogin.api.branding_service_templates_api import BrandingServiceTemplatesApi
from onelogin.api.events_api import EventsApi
from onelogin.api.groups_api import GroupsApi
from onelogin.api.invite_links_api import InviteLinksApi
from onelogin.api.multi_factor_authentication_api import MultiFactorAuthenticationApi
from onelogin.api.multi_factor_authentication_v1_api import MultiFactorAuthenticationV1Api
from onelogin.api.o_auth2_api import OAuth2Api
from onelogin.api.privileges_api import PrivilegesApi
from onelogin.api.roles_api import RolesApi
from onelogin.api.saml_assertions_api import SAMLAssertionsApi
from onelogin.api.smart_hooks_api import SmartHooksApi
from onelogin.api.user_mappings_api import UserMappingsApi
from onelogin.api.users_v1_api import UsersV1Api
from onelogin.api.users_v2_api import UsersV2Api
from onelogin.api.vigilance_ai_api import VigilanceAIApi

# import ApiClient
from onelogin.api_client import ApiClient
from onelogin.configuration import Configuration
from onelogin.exceptions import OpenApiException
from onelogin.exceptions import ApiTypeError
from onelogin.exceptions import ApiValueError
from onelogin.exceptions import ApiKeyError
from onelogin.exceptions import ApiAttributeError
from onelogin.exceptions import ApiException
# import models into sdk package
from onelogin.models.action_obj import ActionObj
from onelogin.models.activate_mfa_factors_request import ActivateMfaFactorsRequest
from onelogin.models.add_client_app201_response import AddClientApp201Response
from onelogin.models.add_client_app_request import AddClientAppRequest
from onelogin.models.add_privilege_to_role201_response import AddPrivilegeToRole201Response
from onelogin.models.add_privilege_to_role_request import AddPrivilegeToRoleRequest
from onelogin.models.add_roles_to_user_request import AddRolesToUserRequest
from onelogin.models.alt_err import AltErr
from onelogin.models.app_parameters import AppParameters
from onelogin.models.app_rule import AppRule
from onelogin.models.assign_users_to_privilege_request import AssignUsersToPrivilegeRequest
from onelogin.models.auth_claim import AuthClaim
from onelogin.models.auth_id import AuthId
from onelogin.models.auth_method import AuthMethod
from onelogin.models.auth_scope import AuthScope
from onelogin.models.auth_server import AuthServer
from onelogin.models.auth_server_configuration import AuthServerConfiguration
from onelogin.models.brand import Brand
from onelogin.models.brand_app import BrandApp
from onelogin.models.brand_background import BrandBackground
from onelogin.models.brand_background_urls import BrandBackgroundUrls
from onelogin.models.brand_logo import BrandLogo
from onelogin.models.brand_logo_urls import BrandLogoUrls
from onelogin.models.brand_req import BrandReq
from onelogin.models.client_app_full import ClientAppFull
from onelogin.models.clock_counter import ClockCounter
from onelogin.models.condition import Condition
from onelogin.models.configuration_oidc import ConfigurationOidc
from onelogin.models.configuration_saml import ConfigurationSaml
from onelogin.models.connector import Connector
from onelogin.models.create_app200_response import CreateApp200Response
from onelogin.models.create_app_request import CreateAppRequest
from onelogin.models.create_device_verification201_response import CreateDeviceVerification201Response
from onelogin.models.create_device_verification_request import CreateDeviceVerificationRequest
from onelogin.models.create_factor_registration201_response import CreateFactorRegistration201Response
from onelogin.models.create_factor_registration_request import CreateFactorRegistrationRequest
from onelogin.models.create_privilege200_response import CreatePrivilege200Response
from onelogin.models.create_role201_response_inner import CreateRole201ResponseInner
from onelogin.models.device import Device
from onelogin.models.email_config import EmailConfig
from onelogin.models.enforcement_point import EnforcementPoint
from onelogin.models.enforcement_point_resources_inner import EnforcementPointResourcesInner
from onelogin.models.enroll_mfa_factor200_response import EnrollMfaFactor200Response
from onelogin.models.error import Error
from onelogin.models.event import Event
from onelogin.models.generate_mf_atoken200_response import GenerateMFAtoken200Response
from onelogin.models.generate_mf_atoken_request import GenerateMFAtokenRequest
from onelogin.models.generate_otp201_response import GenerateOTP201Response
from onelogin.models.generate_otp_request import GenerateOTPRequest
from onelogin.models.generate_saml_assert200_response import GenerateSamlAssert200Response
from onelogin.models.generate_token_request import GenerateTokenRequest
from onelogin.models.generic_app import GenericApp
from onelogin.models.generic_app_provisioning import GenericAppProvisioning
from onelogin.models.get_assigned_user200_response import GetAssignedUser200Response
from onelogin.models.get_auth_factors200_response import GetAuthFactors200Response
from onelogin.models.get_authentication_devices200_response_inner import GetAuthenticationDevices200ResponseInner
from onelogin.models.get_custom_attributes200_response import GetCustomAttributes200Response
from onelogin.models.get_email_settings200_response import GetEmailSettings200Response
from onelogin.models.get_email_settings200_response_one_of import GetEmailSettings200ResponseOneOf
from onelogin.models.get_enrolled_factors200_response import GetEnrolledFactors200Response
from onelogin.models.get_enrolled_factors200_response_data import GetEnrolledFactors200ResponseData
from onelogin.models.get_enrolled_factors200_response_data_otp_devices_inner import GetEnrolledFactors200ResponseDataOtpDevicesInner
from onelogin.models.get_event_by_id200_response import GetEventById200Response
from onelogin.models.get_event_types200_response import GetEventTypes200Response
from onelogin.models.get_event_types200_response_data_inner import GetEventTypes200ResponseDataInner
from onelogin.models.get_events200_response import GetEvents200Response
from onelogin.models.get_events200_response_pagination import GetEvents200ResponsePagination
from onelogin.models.get_groups200_response import GetGroups200Response
from onelogin.models.get_invite_link200_response import GetInviteLink200Response
from onelogin.models.get_invite_link_request import GetInviteLinkRequest
from onelogin.models.get_mfa_factors200_response import GetMFAFactors200Response
from onelogin.models.get_mfa_factors200_response_data import GetMFAFactors200ResponseData
from onelogin.models.get_mfa_factors200_response_data_auth_factors_inner import GetMFAFactors200ResponseDataAuthFactorsInner
from onelogin.models.get_rate_limit200_response import GetRateLimit200Response
from onelogin.models.get_risk_score200_response import GetRiskScore200Response
from onelogin.models.get_risk_score_request import GetRiskScoreRequest
from onelogin.models.get_risk_scores200_response import GetRiskScores200Response
from onelogin.models.get_risk_scores200_response_scores import GetRiskScores200ResponseScores
from onelogin.models.get_role_apps200_response_inner import GetRoleApps200ResponseInner
from onelogin.models.get_role_by_id200_response import GetRoleById200Response
from onelogin.models.get_role_by_id200_response_data_inner import GetRoleById200ResponseDataInner
from onelogin.models.get_role_by_name200_response import GetRoleByName200Response
from onelogin.models.get_role_by_name200_response_data_inner import GetRoleByName200ResponseDataInner
from onelogin.models.get_role_by_name200_response_pagination import GetRoleByName200ResponsePagination
from onelogin.models.get_user_apps200_response_inner import GetUserApps200ResponseInner
from onelogin.models.get_user_roles200_response import GetUserRoles200Response
from onelogin.models.get_user_verification200_response import GetUserVerification200Response
from onelogin.models.group import Group
from onelogin.models.hook import Hook
from onelogin.models.hook_envvar import HookEnvvar
from onelogin.models.hook_log import HookLog
from onelogin.models.hook_options import HookOptions
from onelogin.models.hook_status import HookStatus
from onelogin.models.list_conditions200_response_inner import ListConditions200ResponseInner
from onelogin.models.list_mapping_action_values200_response_inner import ListMappingActionValues200ResponseInner
from onelogin.models.list_mapping_conditions200_response import ListMappingConditions200Response
from onelogin.models.list_mapping_conditions_operators200_response_inner import ListMappingConditionsOperators200ResponseInner
from onelogin.models.list_mapping_contion_values200_response_inner import ListMappingContionValues200ResponseInner
from onelogin.models.list_mappings_actions200_response_inner import ListMappingsActions200ResponseInner
from onelogin.models.list_message_templates200_response_inner import ListMessageTemplates200ResponseInner
from onelogin.models.list_privelege_roles200_response import ListPrivelegeRoles200Response
from onelogin.models.locale import Locale
from onelogin.models.lock_account_user_request import LockAccountUserRequest
from onelogin.models.mapping import Mapping
from onelogin.models.message_template import MessageTemplate
from onelogin.models.message_template_template import MessageTemplateTemplate
from onelogin.models.message_template_template_one_of import MessageTemplateTemplateOneOf
from onelogin.models.message_template_template_one_of1 import MessageTemplateTemplateOneOf1
from onelogin.models.oauth_token import OauthToken
from onelogin.models.oidc_app import OidcApp
from onelogin.models.oidc_app_all_of import OidcAppAllOf
from onelogin.models.otp_device import OtpDevice
from onelogin.models.privilege import Privilege
from onelogin.models.privilege_privilege import PrivilegePrivilege
from onelogin.models.privilege_privilege_statement_inner import PrivilegePrivilegeStatementInner
from onelogin.models.rate_limit import RateLimit
from onelogin.models.remove_role_users_request import RemoveRoleUsersRequest
from onelogin.models.remove_user_role_request import RemoveUserRoleRequest
from onelogin.models.remove_user_role_request_role_id_array_inner import RemoveUserRoleRequestRoleIdArrayInner
from onelogin.models.request_brand import RequestBrand
from onelogin.models.revoke_tokens_request import RevokeTokensRequest
from onelogin.models.risk_device import RiskDevice
from onelogin.models.risk_rule import RiskRule
from onelogin.models.risk_user import RiskUser
from onelogin.models.role import Role
from onelogin.models.rule_action import RuleAction
from onelogin.models.rule_condition import RuleCondition
from onelogin.models.saml_app import SamlApp
from onelogin.models.saml_app_all_of import SamlAppAllOf
from onelogin.models.saml_app_all_of_parameters import SamlAppAllOfParameters
from onelogin.models.saml_app_all_of_parameters_saml_username import SamlAppAllOfParametersSamlUsername
from onelogin.models.saml_assert import SamlAssert
from onelogin.models.saml_factor import SamlFactor
from onelogin.models.scope import Scope
from onelogin.models.send_invite_link200_response import SendInviteLink200Response
from onelogin.models.send_invite_link_request import SendInviteLinkRequest
from onelogin.models.session import Session
from onelogin.models.set_user_state_request import SetUserStateRequest
from onelogin.models.source import Source
from onelogin.models.sso_oidc import SsoOidc
from onelogin.models.sso_saml import SsoSaml
from onelogin.models.sso_saml_certificate import SsoSamlCertificate
from onelogin.models.token_claim import TokenClaim
from onelogin.models.track_risk_event_request import TrackRiskEventRequest
from onelogin.models.update_client_app_request import UpdateClientAppRequest
from onelogin.models.update_environment_variable_request import UpdateEnvironmentVariableRequest
from onelogin.models.update_password_insecure_request import UpdatePasswordInsecureRequest
from onelogin.models.update_password_secure_request import UpdatePasswordSecureRequest
from onelogin.models.update_privilege200_response import UpdatePrivilege200Response
from onelogin.models.update_risk_rule_request import UpdateRiskRuleRequest
from onelogin.models.update_role200_response import UpdateRole200Response
from onelogin.models.user import User
from onelogin.models.ver_factor_saml200_response import VerFactorSaml200Response
from onelogin.models.verb import Verb
from onelogin.models.verify_mfa_factor_request import VerifyMfaFactorRequest
from onelogin.models.verify_user_registration200_response import VerifyUserRegistration200Response
from onelogin.models.verify_user_registration_request import VerifyUserRegistrationRequest
from onelogin.models.verify_user_verification_request import VerifyUserVerificationRequest



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, StrictBool, StrictInt, StrictStr

class BrandApp(BaseModel):
    """
    BrandApp
    """
    id: StrictInt = ...
    updated_at: StrictStr = ...
    name: StrictStr = ...
    connector_id: StrictInt = ...
    auth_method_description: StrictStr = ...
    description: StrictStr = ...
    auth_method: StrictInt = ...
    created_at: StrictStr = ...
    visible: StrictBool = ...
    __properties = ["id", "updated_at", "name", "connector_id", "auth_method_description", "description", "auth_method", "created_at", "visible"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> BrandApp:
        """Create an instance of BrandApp from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> BrandApp:
        """Create an instance of BrandApp from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return BrandApp.parse_obj(obj)

        _obj = BrandApp.parse_obj({
            "id": obj.get("id"),
            "updated_at": obj.get("updated_at"),
            "name": obj.get("name"),
            "connector_id": obj.get("connector_id"),
            "auth_method_description": obj.get("auth_method_description"),
            "description": obj.get("description"),
            "auth_method": obj.get("auth_method"),
            "created_at": obj.get("created_at"),
            "visible": obj.get("visible")
        })
        return _obj




# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from onelogin.models.risk_device import RiskDevice
from onelogin.models.risk_user import RiskUser
from onelogin.models.session import Session
from onelogin.models.source import Source

class TrackRiskEventRequest(BaseModel):
    """
    TrackRiskEventRequest
    """
    verb: StrictStr = Field(..., description="Verbs are used to distinguish between different types of events.")
    ip: StrictStr = Field(..., description="The IP address of the User's request.")
    user_agent: StrictStr = Field(..., description="The user agent of the User's request.")
    user: RiskUser = ...
    source: Optional[Source] = None
    session: Optional[Session] = None
    device: Optional[RiskDevice] = None
    fp: Optional[StrictStr] = Field(None, description="Set to the value of the __tdli_fp cookie.")
    published: Optional[StrictStr] = Field(None, description="Date and time of the event in IS08601 format. Useful for preloading old events. Defaults to date time this API request is received.")
    __properties = ["verb", "ip", "user_agent", "user", "source", "session", "device", "fp", "published"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TrackRiskEventRequest:
        """Create an instance of TrackRiskEventRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of user
        if self.user:
            _dict['user'] = self.user.to_dict()
        # override the default output from pydantic by calling `to_dict()` of source
        if self.source:
            _dict['source'] = self.source.to_dict()
        # override the default output from pydantic by calling `to_dict()` of session
        if self.session:
            _dict['session'] = self.session.to_dict()
        # override the default output from pydantic by calling `to_dict()` of device
        if self.device:
            _dict['device'] = self.device.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TrackRiskEventRequest:
        """Create an instance of TrackRiskEventRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return TrackRiskEventRequest.parse_obj(obj)

        _obj = TrackRiskEventRequest.parse_obj({
            "verb": obj.get("verb"),
            "ip": obj.get("ip"),
            "user_agent": obj.get("user_agent"),
            "user": RiskUser.from_dict(obj.get("user")) if obj.get("user") is not None else None,
            "source": Source.from_dict(obj.get("source")) if obj.get("source") is not None else None,
            "session": Session.from_dict(obj.get("session")) if obj.get("session") is not None else None,
            "device": RiskDevice.from_dict(obj.get("device")) if obj.get("device") is not None else None,
            "fp": obj.get("fp"),
            "published": obj.get("published")
        })
        return _obj




# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr, constr, validator
from onelogin.models.message_template_template import MessageTemplateTemplate

class MessageTemplate(BaseModel):
    """
    MessageTemplate
    """
    id: Optional[StrictInt] = None
    account_id: Optional[StrictInt] = None
    type: StrictStr = Field(..., description="Template type that describes the source (sms, voice, email) and purpose (registration, invite, etc)")
    locale: constr(strict=True) = Field(..., description="The 2 character language locale for the template. e.g. en = English, es = Spanish")
    template: MessageTemplateTemplate = ...
    template_class: Optional[StrictStr] = None
    updated_at: Optional[StrictStr] = Field(None, description="Last time template was updated")
    brand_id: Optional[StrictInt] = Field(None, description="brand id number")
    __properties = ["id", "account_id", "type", "locale", "template", "template_class", "updated_at", "brand_id"]

    @validator('type')
    def type_validate_enum(cls, v):
        if v not in ('email_forgot_password', 'email_code_registration', 'email_code_login_verification', 'email_code_app_verification', 'email_code_pw_reset_verification', 'email_magiclink_registration', 'email_magiclink_login_verification', 'email_magiclink_app_verification', 'email_magiclink_pw_reset_verification', 'sms_registration', 'sms_login_verification', 'sms_app_verification', 'sms_pw_reset_verification'):
            raise ValueError("must be one of enum values ('email_forgot_password', 'email_code_registration', 'email_code_login_verification', 'email_code_app_verification', 'email_code_pw_reset_verification', 'email_magiclink_registration', 'email_magiclink_login_verification', 'email_magiclink_app_verification', 'email_magiclink_pw_reset_verification', 'sms_registration', 'sms_login_verification', 'sms_app_verification', 'sms_pw_reset_verification')")
        return v

    @validator('locale')
    def locale_validate_regular_expression(cls, v):
        if not re.match(r"^[a-z]{2}$", v):
            raise ValueError(r"must validate the regular expression /^[a-z]{2}$/")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> MessageTemplate:
        """Create an instance of MessageTemplate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "id",
                            "account_id",
                            "template_class",
                            "updated_at",
                            "brand_id",
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of template
        if self.template:
            _dict['template'] = self.template.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> MessageTemplate:
        """Create an instance of MessageTemplate from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return MessageTemplate.parse_obj(obj)

        _obj = MessageTemplate.parse_obj({
            "id": obj.get("id"),
            "account_id": obj.get("account_id"),
            "type": obj.get("type"),
            "locale": obj.get("locale"),
            "template": MessageTemplateTemplate.from_dict(obj.get("template")) if obj.get("template") is not None else None,
            "template_class": obj.get("template_class"),
            "updated_at": obj.get("updated_at"),
            "brand_id": obj.get("brand_id")
        })
        return _obj




# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr

class OtpDevice(BaseModel):
    """
    OtpDevice
    """
    factor_id: StrictInt = Field(..., description="The identifier of the factor to enroll the user with.")
    display_name: StrictStr = Field(..., description="A name for the users device")
    number: StrictStr = Field(..., description="The phone number of the user in E.164 format.")
    verified: Optional[StrictBool] = Field(None, description="Defaults to false. Some factors like SMS or Voice require that a user recieve a token and then that token is supplied to the Verify endpoint before the device is considered active. You can set verfied to `true` which indicates the the users phone number is pre verified and the device can be immediately activated.           ")
    __properties = ["factor_id", "display_name", "number", "verified"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> OtpDevice:
        """Create an instance of OtpDevice from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "factor_id",
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> OtpDevice:
        """Create an instance of OtpDevice from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return OtpDevice.parse_obj(obj)

        _obj = OtpDevice.parse_obj({
            "factor_id": obj.get("factor_id"),
            "display_name": obj.get("display_name"),
            "number": obj.get("number"),
            "verified": obj.get("verified")
        })
        return _obj




# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import onelogin
from onelogin.models.saml_app_all_of import SamlAppAllOf  # noqa: E501
from onelogin.rest import ApiException

class TestSamlAppAllOf(unittest.TestCase):
    """SamlAppAllOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SamlAppAllOf
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SamlAppAllOf`
        """
        model = onelogin.models.saml_app_all_of.SamlAppAllOf()  # noqa: E501
        if include_optional :
            return SamlAppAllOf(
                configuration = onelogin.models.configuration_saml.configuration_saml(
                    signature_algorithm = 'SHA-512', 
                    certificate_id = 123456, ), 
                sso = onelogin.models.sso_saml.sso_saml(
                    metadata_url = 'https://app.onelogin.com/saml/metadata/5772393d-2ad3-47d6-a64f-2339b1028291', 
                    acs_url = 'https://sharkbytes.onelogin.com/trust/saml2/http-post/sso/928532', 
                    sls_url = 'https://sharkbytes.onelogin.com/trust/saml2/http-redirect/slo/928532', 
                    issuer = 'https://app.onelogin.com/saml/metadata/5772393d-2ad3-47d6-a64f-2339b1028291', 
                    certificate = onelogin.models.sso_saml_certificate.sso_saml_certificate(
                        id = 170216, 
                        name = 'My Companies SAML Certificate', 
                        value = 'c6d814d032f000d9c03bc79727265', ), ), 
                parameters = onelogin.models.saml_app_all_of_parameters.saml_app_allOf_parameters(
                    saml_username = onelogin.models.saml_app_all_of_parameters_saml_username.saml_app_allOf_parameters_saml_username(
                        user_attribute_mappings = '', ), )
            )
        else :
            return SamlAppAllOf(
        )
        """

    def testSamlAppAllOf(self):
        """Test SamlAppAllOf"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import onelogin
from onelogin.models.event import Event  # noqa: E501
from onelogin.rest import ApiException

class TestEvent(unittest.TestCase):
    """Event unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Event
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Event`
        """
        model = onelogin.models.event.Event()  # noqa: E501
        if include_optional :
            return Event(
                account_id = 56, 
                actor_system = '', 
                actor_user_id = 56, 
                actor_user_name = '', 
                adc_id = 56, 
                app_name = '', 
                app_id = 56, 
                assumed_by_superadmin_or_reseller = 56, 
                assuming_acting_user_id = 56, 
                certificate_id = 56, 
                client_id = '', 
                created_at = '', 
                custom_message = '', 
                directory_sync_run_id = 56, 
                error_description = '', 
                event_type_id = 1, 
                group_name = '', 
                group_id = 56, 
                id = 56, 
                ipaddr = '', 
                mapping_id = 56, 
                notes = '', 
                object_id = 56, 
                otp_device_id = 56, 
                otp_device_name = '', 
                param = '', 
                policy_id = 56, 
                policy_name = '', 
                policy_type = '', 
                privilege_id = 56, 
                proxy_ip = '', 
                radius_config_id = 56, 
                resolved_at = '', 
                resource_type_id = 56, 
                risk_cookie_id = '', 
                risk_reasons = '', 
                risk_score = 56, 
                role_id = 56, 
                role_name = '', 
                service_directory_id = 56, 
                solved = True, 
                trusted_idp_id = 56, 
                user_field_id = 56, 
                user_id = 56, 
                user_name = ''
            )
        else :
            return Event(
        )
        """

    def testEvent(self):
        """Test Event"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, conlist

class TokenClaim(BaseModel):
    """
    TokenClaim
    """
    id: Optional[StrictInt] = Field(None, description="The unique ID of the claim.")
    label: Optional[StrictStr] = Field(None, description="The UI label for the claims.")
    user_attribute_mappings: Optional[StrictStr] = Field(None, description="A user attribute to map values from.")
    user_attribute_macros: Optional[StrictStr] = Field(None, description="When `user_attribute_mappings` is set to `_macro_` this macro will be used to assign the claims value.")
    attribute_transformations: Optional[StrictStr] = Field(None, description="The type of transformation to perform on multi valued attributes.")
    skip_if_blank: Optional[StrictBool] = Field(None, description="not used")
    values: Optional[conlist(StrictStr)] = Field(None, description="Relates to Rules/Entitlements. Not supported yet.")
    default_values: Optional[StrictStr] = Field(None, description="Relates to Rules/Entitlements. Not supported yet.")
    provisioned_entitlements: Optional[StrictBool] = Field(None, description="Relates to Rules/Entitlements. Not supported yet.")
    __properties = ["id", "label", "user_attribute_mappings", "user_attribute_macros", "attribute_transformations", "skip_if_blank", "values", "default_values", "provisioned_entitlements"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TokenClaim:
        """Create an instance of TokenClaim from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TokenClaim:
        """Create an instance of TokenClaim from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return TokenClaim.parse_obj(obj)

        _obj = TokenClaim.parse_obj({
            "id": obj.get("id"),
            "label": obj.get("label"),
            "user_attribute_mappings": obj.get("user_attribute_mappings"),
            "user_attribute_macros": obj.get("user_attribute_macros"),
            "attribute_transformations": obj.get("attribute_transformations"),
            "skip_if_blank": obj.get("skip_if_blank"),
            "values": obj.get("values"),
            "default_values": obj.get("default_values"),
            "provisioned_entitlements": obj.get("provisioned_entitlements")
        })
        return _obj




# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import onelogin
from onelogin.models.oidc_app_all_of import OidcAppAllOf  # noqa: E501
from onelogin.rest import ApiException

class TestOidcAppAllOf(unittest.TestCase):
    """OidcAppAllOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test OidcAppAllOf
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OidcAppAllOf`
        """
        model = onelogin.models.oidc_app_all_of.OidcAppAllOf()  # noqa: E501
        if include_optional :
            return OidcAppAllOf(
                configuration = onelogin.models.configuration_oidc.configuration_oidc(
                    login_url = '', 
                    redirect_uri = 'https://localhost:3000/callback', 
                    access_token_expiration_minutes = 1, 
                    refresh_token_expiration_minutes = 1, 
                    token_endpoint_auth_method = 0, 
                    oidc_application_type = 0, ), 
                sso = onelogin.models.sso_oidc.sso_oidc(
                    client_id = '78d1d040-20c9-0136-5146-067351775fae92920', )
            )
        else :
            return OidcAppAllOf(
                configuration = onelogin.models.configuration_oidc.configuration_oidc(
                    login_url = '', 
                    redirect_uri = 'https://localhost:3000/callback', 
                    access_token_expiration_minutes = 1, 
                    refresh_token_expiration_minutes = 1, 
                    token_endpoint_auth_method = 0, 
                    oidc_application_type = 0, ),
        )
        """

    def testOidcAppAllOf(self):
        """Test OidcAppAllOf"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import onelogin
from onelogin.models.get_enrolled_factors200_response_data_otp_devices_inner import GetEnrolledFactors200ResponseDataOtpDevicesInner  # noqa: E501
from onelogin.rest import ApiException

class TestGetEnrolledFactors200ResponseDataOtpDevicesInner(unittest.TestCase):
    """GetEnrolledFactors200ResponseDataOtpDevicesInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test GetEnrolledFactors200ResponseDataOtpDevicesInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetEnrolledFactors200ResponseDataOtpDevicesInner`
        """
        model = onelogin.models.get_enrolled_factors200_response_data_otp_devices_inner.GetEnrolledFactors200ResponseDataOtpDevicesInner()  # noqa: E501
        if include_optional :
            return GetEnrolledFactors200ResponseDataOtpDevicesInner(
                active = True, 
                default = False, 
                state_token = 'f2402de2b446abd86ea5aa1f79b3fa72b4befacd', 
                auth_factor_name = 'Onelogin SMS', 
                phone_number = '+1xxxxxxxxxx', 
                type_display_name = 'Onelogin SMS', 
                needs_trigger = True, 
                user_display_name = 'Rich's Phone', 
                id = 525509
            )
        else :
            return GetEnrolledFactors200ResponseDataOtpDevicesInner(
        )
        """

    def testGetEnrolledFactors200ResponseDataOtpDevicesInner(self):
        """Test GetEnrolledFactors200ResponseDataOtpDevicesInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
